@@ -1,5 +1,5 @@
 package Net::Stripe;
-$Net::Stripe::VERSION = '0.25';
+$Net::Stripe::VERSION = '0.27';
 use Moose;
 use Kavorka;
 use LWP::UserAgent;
@@ -21,6 +21,7 @@ use Net::Stripe::Error;
 use Net::Stripe::BalanceTransaction;
 use Net::Stripe::List;
 use Net::Stripe::LineItem;
+use Net::Stripe::Refund;
 
 # ABSTRACT: API client for Stripe.com
 
@@ -65,13 +66,10 @@ Charges: {
             $charge = $charge->id;
         }
         
-        if($amount) {
-            $amount = "?amount=$amount";
-        } else {
-            $amount = '';
-        }
-        
-        return $self->_post("charges/$charge/refund" . $amount);
+        my $refund = Net::Stripe::Refund->new(id => $charge,
+                                              amount => $amount
+                                          );
+        return $self->_post("charges/$charge/refunds", $refund);
     }
 
     method get_charges(HashRef :$created?, 
@@ -732,7 +730,7 @@ Net::Stripe - API client for Stripe.com
 
 =head1 VERSION
 
-version 0.25
+version 0.27
 
 =head1 SYNOPSIS
 
@@ -913,7 +911,7 @@ L<https://stripe.com/docs/api#refund_charge>
 
 =back
 
-Returns a new L<Net::Stripe::Charge>.
+Returns a new L<Net::Stripe::Refund>.
 
   $stripe->refund_charge(charge => $charge, amount => 500);
 
@@ -1673,7 +1671,7 @@ Rusty Conover
 
 =head1 CONTRIBUTORS
 
-=for stopwords Andrew Solomon Tom Eliaz Brian Collins Devin M. Certas Dimitar Petrov Dylan Reinhold Jonathan "Duke" Leto Luke Closs Olaf Alders Rusty Conover Sachin Sebastian
+=for stopwords Andrew Solomon Sachin Sebastian Tom Eliaz Brian Collins Devin M. Certas Dimitar Petrov Dylan Reinhold Hermann Calabria Jonathan "Duke" Leto Luke Closs Olaf Alders Rusty Conover
 
 =over 4
 
@@ -1683,6 +1681,10 @@ Andrew Solomon <andrew@illywhacker.net>
 
 =item *
 
+Sachin Sebastian <sachinjsk@users.noreply.github.com>
+
+=item *
+
 Tom Eliaz <tom@tomeliaz.com>
 
 =item *
@@ -1703,6 +1705,10 @@ Dylan Reinhold <dylan@gasdasoftware.com>
 
 =item *
 
+Hermann Calabria <hermann@ivouch.com>
+
+=item *
+
 Jonathan "Duke" Leto <jonathan@leto.net>
 
 =item *
@@ -1717,10 +1723,6 @@ Olaf Alders <olaf@wundersolutions.com>
 
 Rusty Conover <rusty@luckydinosaur.com>
 
-=item *
-
-Sachin Sebastian <sachinjsk@users.noreply.github.com>
-
 =back
 
 =head1 COPYRIGHT AND LICENSE
