@@ -1,5 +1,5 @@
 package Net::Stripe::Card;
-$Net::Stripe::Card::VERSION = '0.25';
+$Net::Stripe::Card::VERSION = '0.27';
 use Moose;
 use Moose::Util::TypeConstraints qw(union);
 use Kavorka;
@@ -29,7 +29,7 @@ has 'country'              => (is => 'ro', isa => 'Maybe[Str]');
 has 'cvc_check'            => (is => 'ro', isa => 'Maybe[Str]');
 has 'fingerprint'          => (is => 'ro', isa => 'Maybe[Str]');
 has 'last4'                => (is => 'ro', isa => 'Maybe[Str]');
-has 'type'                 => (is => 'ro', isa => 'Maybe[Str]');
+has 'brand'                => (is => 'ro', isa => 'Maybe[Str]');  # formerly 'type'
 
 method form_fields {
     return (
@@ -53,7 +53,7 @@ Net::Stripe::Card - represent a Card object from Stripe
 
 =head1 VERSION
 
-version 0.25
+version 0.27
 
 =head1 ATTRIBUTES
 
@@ -99,6 +99,12 @@ Reader: address_zip_check
 
 Type: Maybe[Str]
 
+=head2 brand
+
+Reader: brand
+
+Type: Maybe[Str]
+
 =head2 country
 
 Reader: country
@@ -163,12 +169,6 @@ Reader: number
 
 Type: Maybe[Str]
 
-=head2 type
-
-Reader: type
-
-Type: Maybe[Str]
-
 =head1 AUTHORS
 
 =over 4
