@@ -1,6 +1,5 @@
 package Net::Stripe::Refund;
-$Net::Stripe::Refund::VERSION = '0.42_002'; # TRIAL
-$Net::Stripe::Refund::VERSION = '0.42002';
+$Net::Stripe::Refund::VERSION = '0.27';
 use Moose;
 use Kavorka;
 extends 'Net::Stripe::Resource';
@@ -16,24 +15,17 @@ has 'charge'              => (is => 'ro', isa => 'Maybe[Str]');
 has 'metadata'            => (is => 'ro', isa => 'Maybe[HashRef]');
 has 'reason'              => (is => 'ro', isa => 'Maybe[Str]');
 has 'receipt_number'      => (is => 'ro', isa => 'Maybe[Str]');
-has 'status'              => (is => 'ro', isa => 'Maybe[Str]');
-has 'description'         => (
-    is      => 'ro',
-    isa     => 'Maybe[Str]',
-    lazy    => 1,
-    default => sub {
-        warn
-            "Use of Net::Stripe::Refund->description is deprecated and will be removed in the next Net::Stripe release";
-        return;
-    }
-);
+has 'description'         => (is => 'ro', isa => 'Maybe[Str]');
 
 # Create only
 has 'refund_application_fee' => (is => 'ro', isa => 'Maybe[Bool|Object]');
 
 method form_fields {
-    return $self->form_fields_for(
-        qw/amount refund_application_fee reason metadata/
+    return (
+        $self->form_fields_for_metadata(),
+        map { $_ => $self->$_ }
+            grep { defined $self->$_ }
+                qw/amount refund_application_fee reason/
     );
 }
 
@@ -50,7 +42,7 @@ Net::Stripe::Refund - represent a Refund object from Stripe
 
 =head1 VERSION
 
-version 0.42_002
+version 0.27
 
 =head1 ATTRIBUTES
 
@@ -66,12 +58,6 @@ Reader: balance_transaction
 
 Type: Maybe[Str]
 
-=head2 boolean_attributes
-
-Reader: boolean_attributes
-
-Type: ArrayRef[Str]
-
 =head2 charge
 
 Reader: charge
@@ -126,12 +112,6 @@ Reader: refund_application_fee
 
 Type: Maybe[Bool|Object]
 
-=head2 status
-
-Reader: status
-
-Type: Maybe[Str]
-
 =head1 AUTHORS
 
 =over 4
@@ -148,7 +128,7 @@ Rusty Conover
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Prime Radiant, Inc., (c) copyright 2014 Lucky Dinosaur LLC.
+This software is copyright (c) 2011 by Prime Radiant, Inc., (c) copyright 2014 Lucky Dinosaur LLC..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
